"use strict";
/*
 * Copyright (c) 2018-2023, NeKz
 *
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetMessages = exports.SvcPaintMapData = exports.SvcCmdKeyValues = exports.SvcGetCvarValue = exports.SvcGameEventList = exports.SvcMenu = exports.SvcPrefetch = exports.SvcTempEntities = exports.SvcPacketEntities = exports.SvcGameEvent = exports.SvcEntityMessage = exports.SvcUserMessage = exports.SvcSplitScreen = exports.SvcBspDecal = exports.SvcCrosshairAngle = exports.SvcFixAngle = exports.SvcSetView = exports.SvcSounds = exports.SvcPrint = exports.SvcVoiceData = exports.SvcVoiceInit = exports.SvcUpdateStringTable = exports.SvcCreateStringTable = exports.SvcSetPause = exports.SvcClassInfo = exports.SvcSendTable = exports.SvcServerInfo = exports.NetSignonState = exports.NetSetConVar = exports.NetStringCmd = exports.NetTick = exports.NetSplitScreenUser = exports.NetFile = exports.NetDisconnect = exports.NetNop = exports.NetMessage = void 0;
const SoundInfo_js_1 = require("./SoundInfo.js");
const GameEventManager_js_1 = require("./GameEventManager.js");
class NetMessage {
    constructor(type) {
        Object.defineProperty(this, "type", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.type = type;
    }
    getType() {
        return this.type;
    }
    getName() {
        return this.constructor.name;
    }
    read(_buf, _demo) {
        throw new Error(`read() for ${this.constructor.name} not implemented!`);
    }
}
exports.NetMessage = NetMessage;
class NetNop extends NetMessage {
    read() { }
}
exports.NetNop = NetNop;
class NetDisconnect extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "text", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.text = buf.readASCIIString();
    }
}
exports.NetDisconnect = NetDisconnect;
class NetFile extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "transferId", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "fileName", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "fileRequested", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.transferId = buf.readInt32();
        this.fileName = buf.readASCIIString();
        this.fileRequested = buf.readBoolean();
    }
}
exports.NetFile = NetFile;
class NetSplitScreenUser extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "unk", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.unk = buf.readBoolean();
    }
}
exports.NetSplitScreenUser = NetSplitScreenUser;
class NetTick extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "tick", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "hostFrameTime", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "hostFrameTimeStdDeviation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        const NET_TICK_SCALEUP = 100000;
        this.tick = buf.readInt32();
        this.hostFrameTime = buf.readInt16() / NET_TICK_SCALEUP;
        this.hostFrameTimeStdDeviation = buf.readInt16() / NET_TICK_SCALEUP;
    }
}
exports.NetTick = NetTick;
class NetStringCmd extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "command", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.command = buf.readASCIIString();
    }
}
exports.NetStringCmd = NetStringCmd;
class NetSetConVar extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "convars", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.convars = [];
        let length = buf.readInt8();
        while (length--) {
            this.convars.push({
                name: buf.readASCIIString(),
                value: buf.readASCIIString(),
            });
        }
    }
}
exports.NetSetConVar = NetSetConVar;
class NetSignonState extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "signonState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "spawnCount", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "numServerPlayers", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "playersNetworkIds", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "mapName", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf, demo) {
        this.signonState = buf.readInt8();
        this.spawnCount = buf.readInt32();
        if (demo.isNewEngine()) {
            this.numServerPlayers = buf.readInt32();
            let length = buf.readInt32();
            if (length > 0) {
                this.playersNetworkIds = buf.readArrayBuffer(length);
            }
            length = buf.readInt32();
            if (length > 0) {
                this.mapName = buf.readASCIIString(length);
            }
        }
    }
}
exports.NetSignonState = NetSignonState;
class SvcServerInfo extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "protocol", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "serverCount", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "isHltv", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "isDedicated", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "clientCrc", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "maxClasses", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "mapCrc", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "playerSlot", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "maxClients", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "unk", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "tickInterval", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cOs", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "gameDir", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "mapName", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "skyName", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "hostName", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf, demo) {
        this.protocol = buf.readInt16();
        this.serverCount = buf.readInt32();
        this.isHltv = buf.readBoolean();
        this.isDedicated = buf.readBoolean();
        this.clientCrc = buf.readInt32();
        this.maxClasses = buf.readInt16();
        this.mapCrc = buf.readInt32();
        this.playerSlot = buf.readInt8();
        this.maxClients = buf.readInt8();
        if (demo.isNewEngine()) {
            this.unk = buf.readInt32();
        }
        else if (demo.networkProtocol === 24) {
            this.unk = buf.readBits(96);
        }
        this.tickInterval = buf.readFloat32();
        this.cOs = String.fromCharCode(buf.readInt8());
        this.gameDir = buf.readASCIIString();
        this.mapName = buf.readASCIIString();
        this.skyName = buf.readASCIIString();
        this.hostName = buf.readASCIIString();
    }
}
exports.SvcServerInfo = SvcServerInfo;
class SvcSendTable extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "needsDecoder", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "props", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.needsDecoder = buf.readBoolean();
        const length = buf.readInt16();
        this.props = buf.readBits(length);
    }
}
exports.SvcSendTable = SvcSendTable;
class SvcClassInfo extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "createOnClient", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "serverClasses", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        let length = buf.readInt16();
        this.createOnClient = buf.readBoolean();
        if (!this.createOnClient) {
            this.serverClasses = [];
            while (length--) {
                this.serverClasses.push({
                    classId: buf.readBits(Math.log2(length) + 1),
                    className: buf.readASCIIString(),
                    dataTableName: buf.readASCIIString(),
                });
            }
        }
    }
}
exports.SvcClassInfo = SvcClassInfo;
class SvcSetPause extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "paused", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.paused = buf.readBoolean();
    }
}
exports.SvcSetPause = SvcSetPause;
class SvcCreateStringTable extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "maxEntries", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "numEntries", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "userDataFixedSize", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "userDataSize", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "userDataSizeBits", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "flags", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "stringData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf, demo) {
        this.name = buf.readASCIIString();
        this.maxEntries = buf.readInt16();
        this.numEntries = buf.readBits(Math.log2(this.maxEntries) + 1);
        const length = buf.readBits(20);
        this.userDataFixedSize = buf.readBoolean();
        this.userDataSize = this.userDataFixedSize ? buf.readBits(12) : 0;
        this.userDataSizeBits = this.userDataFixedSize ? buf.readBits(4) : 0;
        this.flags = buf.readBits(demo.isNewEngine() ? 2 : 1);
        this.stringData = buf.readBits(length);
    }
}
exports.SvcCreateStringTable = SvcCreateStringTable;
class SvcUpdateStringTable extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "tableId", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "numChangedEntries", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "stringData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.tableId = buf.readBits(5);
        this.numChangedEntries = buf.readBoolean() ? buf.readInt16() : 1;
        const length = buf.readBits(20);
        this.stringData = buf.readBits(length);
    }
}
exports.SvcUpdateStringTable = SvcUpdateStringTable;
class SvcVoiceInit extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "codec", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "quality", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "unk", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.codec = buf.readASCIIString();
        this.quality = buf.readInt8();
        if (this.quality === 255)
            this.unk = buf.readFloat32();
    }
}
exports.SvcVoiceInit = SvcVoiceInit;
class SvcVoiceData extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "client", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "proximity", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "voiceData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.client = buf.readInt8();
        this.proximity = buf.readInt8();
        const length = buf.readInt16();
        this.voiceData = buf.readBits(length);
    }
}
exports.SvcVoiceData = SvcVoiceData;
class SvcPrint extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "message", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.message = buf.readASCIIString();
    }
}
exports.SvcPrint = SvcPrint;
class SvcSounds extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "reliableSound", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "sounds", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf, demo) {
        this.reliableSound = buf.readBoolean();
        let sounds = this.reliableSound ? 1 : buf.readBits(8);
        const length = this.reliableSound ? buf.readBits(8) : buf.readBits(16);
        const data = buf.readBitStream(length);
        if (demo.demoProtocol === 3) {
            this.sounds = [];
            while (sounds--) {
                const sound = new SoundInfo_js_1.SoundInfo();
                sound.read(data);
                this.sounds.push(sound);
            }
        }
    }
}
exports.SvcSounds = SvcSounds;
class SvcSetView extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "entityIndex", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.entityIndex = buf.readBits(11);
    }
}
exports.SvcSetView = SvcSetView;
class SvcFixAngle extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "relative", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "angle", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.relative = buf.readBoolean();
        this.angle = [buf.readInt16(), buf.readInt16(), buf.readInt16()];
    }
}
exports.SvcFixAngle = SvcFixAngle;
class SvcCrosshairAngle extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "angle", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.angle = [buf.readInt16(), buf.readInt16(), buf.readInt16()];
    }
}
exports.SvcCrosshairAngle = SvcCrosshairAngle;
class SvcBspDecal extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "pos", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "decalTextureIndex", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "entityIndex", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "modelIndex", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "lowPriority", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.pos = buf.readVectorCoord();
        this.decalTextureIndex = buf.readBits(9);
        if (buf.readBoolean()) {
            this.entityIndex = buf.readBits(11);
            this.modelIndex = buf.readBits(11);
        }
        this.lowPriority = buf.readBoolean();
    }
}
exports.SvcBspDecal = SvcBspDecal;
class SvcSplitScreen extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "unk", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.unk = buf.readBits(1);
        const length = buf.readBits(11);
        this.data = buf.readBits(length);
    }
}
exports.SvcSplitScreen = SvcSplitScreen;
class SvcUserMessage extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "msgType", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "msgData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf, demo) {
        this.msgType = buf.readInt8();
        const length = buf.readBits(demo.isNewEngine() ? 12 : 11);
        this.msgData = buf.readBits(length);
    }
}
exports.SvcUserMessage = SvcUserMessage;
class SvcEntityMessage extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "entityIndex", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "classId", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.entityIndex = buf.readBits(11);
        this.classId = buf.readBits(9);
        const length = buf.readBits(11);
        buf.readBits(length);
    }
}
exports.SvcEntityMessage = SvcEntityMessage;
class SvcGameEvent extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "event", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf, demo) {
        const length = buf.readBits(11);
        const data = buf.readBitStream(length);
        if (demo.gameEventManager) {
            this.event = demo.gameEventManager.deserializeEvent(data);
        }
        else {
            this.data = data;
        }
    }
}
exports.SvcGameEvent = SvcGameEvent;
class SvcPacketEntities extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "maxEntries", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "isDelta", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "deltaFrom", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "baseLine", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "updatedEntries", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "updateBaseline", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.maxEntries = buf.readBits(11);
        this.isDelta = buf.readBoolean();
        this.deltaFrom = this.isDelta ? buf.readInt32() : 0;
        this.baseLine = buf.readBoolean();
        this.updatedEntries = buf.readBits(11);
        const length = buf.readBits(20);
        this.updateBaseline = buf.readBoolean();
        this.data = buf.readBits(length);
    }
}
exports.SvcPacketEntities = SvcPacketEntities;
class SvcTempEntities extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "numEntries", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.numEntries = buf.readInt8();
        const length = buf.readBits(17);
        this.data = buf.readBitStream(length);
    }
}
exports.SvcTempEntities = SvcTempEntities;
class SvcPrefetch extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "soundIndex", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.soundIndex = buf.readBits(13);
    }
}
exports.SvcPrefetch = SvcPrefetch;
class SvcMenu extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "menuType", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.menuType = buf.readInt16();
        const length = buf.readInt32();
        this.data = buf.readBits(length);
    }
}
exports.SvcMenu = SvcMenu;
class SvcGameEventList extends NetMessage {
    read(buf, demo) {
        let events = buf.readBits(9);
        const length = buf.readBits(20);
        const data = buf.readBitStream(length);
        const gameEvents = [];
        while (events--) {
            const descriptor = new GameEventManager_js_1.GameEventDescriptor();
            descriptor.read(data);
            gameEvents.push(descriptor);
        }
        demo.gameEventManager = new GameEventManager_js_1.GameEventManager(gameEvents);
    }
}
exports.SvcGameEventList = SvcGameEventList;
class SvcGetCvarValue extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "cookie", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cvarName", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        this.cookie = buf.readInt32();
        this.cvarName = buf.readASCIIString();
    }
}
exports.SvcGetCvarValue = SvcGetCvarValue;
class SvcCmdKeyValues extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "buffer", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        const length = buf.readInt32();
        this.buffer = buf.readArrayBuffer(length);
    }
}
exports.SvcCmdKeyValues = SvcCmdKeyValues;
class SvcPaintMapData extends NetMessage {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    read(buf) {
        const length = buf.readInt32();
        this.data = buf.readBitStream(length);
    }
}
exports.SvcPaintMapData = SvcPaintMapData;
exports.NetMessages = {
    Portal2Engine: [
        NetNop,
        NetDisconnect,
        NetFile,
        NetSplitScreenUser,
        NetTick,
        NetStringCmd,
        NetSetConVar,
        NetSignonState,
        SvcServerInfo,
        SvcSendTable,
        SvcClassInfo,
        SvcSetPause,
        SvcCreateStringTable,
        SvcUpdateStringTable,
        SvcVoiceInit,
        SvcVoiceData,
        SvcPrint,
        SvcSounds,
        SvcSetView,
        SvcFixAngle,
        SvcCrosshairAngle,
        SvcBspDecal,
        SvcSplitScreen,
        SvcUserMessage,
        SvcEntityMessage,
        SvcGameEvent,
        SvcPacketEntities,
        SvcTempEntities,
        SvcPrefetch,
        SvcMenu,
        SvcGameEventList,
        SvcGetCvarValue,
        SvcCmdKeyValues,
        SvcPaintMapData, // 33
    ],
    HalfLife2Engine: [
        NetNop,
        NetDisconnect,
        NetFile,
        NetTick,
        NetStringCmd,
        NetSetConVar,
        NetSignonState,
        SvcPrint,
        SvcServerInfo,
        SvcSendTable,
        SvcClassInfo,
        SvcSetPause,
        SvcCreateStringTable,
        SvcUpdateStringTable,
        SvcVoiceInit,
        SvcVoiceData,
        undefined,
        SvcSounds,
        SvcSetView,
        SvcFixAngle,
        SvcCrosshairAngle,
        SvcBspDecal,
        undefined,
        SvcUserMessage,
        SvcEntityMessage,
        SvcGameEvent,
        SvcPacketEntities,
        SvcTempEntities,
        SvcPrefetch,
        SvcMenu,
        SvcGameEventList,
        SvcGetCvarValue,
        SvcCmdKeyValues, // 32
    ],
    NetMessage,
    NetNop,
    NetDisconnect,
    NetFile,
    NetSplitScreenUser,
    NetTick,
    NetStringCmd,
    NetSetConVar,
    NetSignonState,
    SvcServerInfo,
    SvcSendTable,
    SvcClassInfo,
    SvcSetPause,
    SvcCreateStringTable,
    SvcUpdateStringTable,
    SvcVoiceInit,
    SvcVoiceData,
    SvcPrint,
    SvcSounds,
    SvcSetView,
    SvcFixAngle,
    SvcCrosshairAngle,
    SvcBspDecal,
    SvcSplitScreen,
    SvcUserMessage,
    SvcEntityMessage,
    SvcGameEvent,
    SvcPacketEntities,
    SvcTempEntities,
    SvcPrefetch,
    SvcMenu,
    SvcGameEventList,
    SvcGetCvarValue,
    SvcCmdKeyValues,
    SvcPaintMapData,
};
